Module decode

Module decode 

Available on crate feature resp2 only.
Decoding functions for BytesMut and slices. Functions for decoding the RESP2 protocol into frames.

https://redis.io/topics/protocol#resp-protocol-description

Functions

decode
Attempt to decode the contents of buf, returning the first valid frame and the number of bytes consumed.
decode_bytesbytes
Attempt to decode the provided buffer without moving or copying the inner buffer contents.
decode_bytes_mutbytes
Attempt to decode and split the provided buffer without moving or copying the inner buffer contents.
decode_range
Attempt to the decode the contents of buf, returning frames that reference ranges into the provided buffer.