BytesFrame

Enum BytesFrame 

pub enum BytesFrame {
    SimpleString(Bytes),
    Error(Str),
    Integer(i64),
    BulkString(Bytes),
    Array(Vec<BytesFrame>),
    Null,
}
Available on crate feature bytes only.
A RESP2 frame that uses Bytes and Str as the underlying buffer type.

Variants



SimpleString(Bytes)

A RESP2 simple string.



Error(Str)

A short string representing an error.



Integer(i64)

A signed 64-bit integer.



BulkString(Bytes)

A byte array.



Array(Vec<BytesFrame>)

An array of frames.



Null

A null value.

Implementations

Source

impl BytesFrame

pub fn to_owned_frame(&self) -> OwnedFrame

Available on crate feature resp2 only.

Copy the contents into a new OwnedFrame.

pub fn into_resp3(self) -> Resp3BytesFrame

Available on crate feature resp2 only.

Convert the frame to RESP3.

For the most part RESP3 is a superset of RESP2, but there is one notable difference with publish-subscribe messages - in RESP3 pubsub arrays have an additional prefix frame with the SimpleString value “pubsub”. This function will add this frame.