FrameKind

Enum FrameKind 

pub enum FrameKind {
    SimpleString,
    Error,
    Integer,
    BulkString,
    Array,
    Null,
}
Available on crate feature resp2 only.
An enum representing the type of RESP frame.

Variants



SimpleString



Error



Integer



BulkString



Array



Null

Implementations

Source

impl FrameKind

pub fn is_error(&self) -> bool

Whether the frame is an error.

pub fn from_byte(d: u8) -> Option<FrameKind>

Read the frame type from the RESP2 byte prefix.

pub fn to_byte(&self) -> u8

Convert to the associated RESP2 byte prefix.

pub fn hash_prefix(&self) -> &'static str

A function used to differentiate data types that may have the same inner binary representation when hashing.