BytesFrame

Enum BytesFrame 

pub enum BytesFrame {
Show 16 variants BlobString { data: Bytes, attributes: Option<BytesAttributes>, }, BlobError { data: Bytes, attributes: Option<BytesAttributes>, }, SimpleString { data: Bytes, attributes: Option<BytesAttributes>, }, SimpleError { data: Str, attributes: Option<BytesAttributes>, }, Boolean { data: bool, attributes: Option<BytesAttributes>, }, Null, Number { data: i64, attributes: Option<BytesAttributes>, }, Double { data: f64, attributes: Option<BytesAttributes>, }, BigNumber { data: Bytes, attributes: Option<BytesAttributes>, }, VerbatimString { data: Bytes, format: VerbatimStringFormat, attributes: Option<BytesAttributes>, }, Array { data: Vec<BytesFrame>, attributes: Option<BytesAttributes>, }, Map { data: FrameMap<BytesFrame, BytesFrame>, attributes: Option<BytesAttributes>, }, Set { data: FrameSet<BytesFrame>, attributes: Option<BytesAttributes>, }, Push { data: Vec<BytesFrame>, attributes: Option<BytesAttributes>, }, Hello { version: RespVersion, auth: Option<(Str, Str)>, setname: Option<Str>, }, ChunkedString(Bytes),
}
Available on crate feature bytes only.
A RESP3 frame that uses Bytes and Str as the underlying buffer type.

https://github.com/antirez/RESP3/blob/master/spec.md

Variants



BlobString

A blob of bytes.

Fields

data: Bytes


BlobError

A blob representing an error.

Fields

data: Bytes


SimpleString

A small string.

The internal data type is Bytes in order to support callers that use this interface to parse a MONITOR stream.

Fields

data: Bytes


SimpleError

A small string representing an error.

Fields

data: Str


Boolean

A boolean type.

Fields

data: bool


Null

A null type.



Number

A signed 64-bit integer.

Fields

data: i64


Double

A signed 64-bit floating point number.

Fields

data: f64


BigNumber

A large number not representable as a Number or Double.

This library does not attempt to parse this.

Fields

data: Bytes


VerbatimString

A string to be displayed without any escaping or filtering.



Array

An array of frames.

Fields



Map

An unordered map of key-value pairs.

According to the spec keys can be any other RESP3 data type. However, it doesn’t make sense to implement Hash for certain aggregate types. The can_hash function can be used to detect this.



Set

An unordered collection of other frames with a uniqueness constraint.



Push

Out-of-band data.

Fields



Hello

A special frame type used when first connecting to the server to describe the protocol version and optional credentials.

Fields

version: RespVersion
auth: Option<(Str, Str)>
setname: Option<Str>


ChunkedString(Bytes)

One chunk of a streaming blob.

Implementations

Source

impl BytesFrame

pub fn to_owned_frame(&self) -> OwnedFrame

Available on crate feature resp3 only.

Copy the frame contents into a new OwnedFrame.