pub enum DecodedRangeFrame {
    Complete(RangeFrame),
    Streaming(StreamedRangeFrame),
}
Available on crate feature resp3 only.
A reference-free frame type representing ranges into an associated buffer, typically used to implement zero-copy parsing.

Variants

Implementations

source

impl DecodedRangeFrame

source

pub fn add_attributes( &mut self, attributes: RangeAttributes ) -> Result<(), RedisProtocolError>

Add attributes to the decoded frame, if possible.

source

pub fn into_complete_frame(self) -> Result<RangeFrame, RedisProtocolError>

Convert the decoded frame to a complete frame, returning an error if a streaming variant is found.