Enum redis_protocol::resp3::types::FrameKind
source · pub enum FrameKind {
Show 18 variants
Array,
BlobString,
SimpleString,
SimpleError,
Number,
Null,
Double,
Boolean,
BlobError,
VerbatimString,
Map,
Set,
Attribute,
Push,
Hello,
BigNumber,
ChunkedString,
EndStream,
}Available on crate feature
resp3 only.Expand description
The type of frame without any associated data.
Variants
Array
BlobString
SimpleString
SimpleError
Number
Null
Double
Boolean
BlobError
VerbatimString
Map
Set
Attribute
Push
Hello
BigNumber
ChunkedString
EndStream
Implementations
sourceimpl FrameKind
impl FrameKind
sourcepub fn is_aggregate_type(&self) -> bool
pub fn is_aggregate_type(&self) -> bool
Whether the frame is an aggregate type (array, set, map).
sourcepub fn is_streaming_type(&self) -> bool
pub fn is_streaming_type(&self) -> bool
Whether the frame is an aggregate type or blob string.
sourcepub fn can_hash(&self) -> bool
pub fn can_hash(&self) -> bool
Whether the frame can be used as a key in a HashMap or HashSet.
Not all frame types can be hashed, and trying to do so can panic. This function can be used to handle this gracefully.
sourcepub fn hash_prefix(&self) -> &'static str
pub fn hash_prefix(&self) -> &'static str
A function used to differentiate data types that may have the same inner binary representation when hashing.