Enum redis_protocol::resp3::types::OwnedFrame
source · pub enum OwnedFrame {
Show 16 variants
BlobString {
data: Vec<u8>,
attributes: Option<OwnedAttributes>,
},
BlobError {
data: Vec<u8>,
attributes: Option<OwnedAttributes>,
},
SimpleString {
data: Vec<u8>,
attributes: Option<OwnedAttributes>,
},
SimpleError {
data: String,
attributes: Option<OwnedAttributes>,
},
Boolean {
data: bool,
attributes: Option<OwnedAttributes>,
},
Null,
Number {
data: i64,
attributes: Option<OwnedAttributes>,
},
Double {
data: f64,
attributes: Option<OwnedAttributes>,
},
BigNumber {
data: Vec<u8>,
attributes: Option<OwnedAttributes>,
},
VerbatimString {
data: Vec<u8>,
format: VerbatimStringFormat,
attributes: Option<OwnedAttributes>,
},
Array {
data: Vec<OwnedFrame>,
attributes: Option<OwnedAttributes>,
},
Map {
data: FrameMap<OwnedFrame, OwnedFrame>,
attributes: Option<OwnedAttributes>,
},
Set {
data: FrameSet<OwnedFrame>,
attributes: Option<OwnedAttributes>,
},
Push {
data: Vec<OwnedFrame>,
attributes: Option<OwnedAttributes>,
},
Hello {
version: RespVersion,
auth: Option<(String, String)>,
setname: Option<String>,
},
ChunkedString(Vec<u8>),
}resp3 only.Expand description
An enum describing a RESP3 frame that uses owned byte containers.
Variants
BlobString
A blob of bytes.
BlobError
A blob representing an error.
SimpleString
A small string.
The internal data type is Vec<u8> in order to support callers that use this interface to parse a MONITOR
stream.
SimpleError
A small string representing an error.
Boolean
A boolean type.
Null
A null type.
Number
A signed 64-bit integer.
Double
A signed 64-bit floating point number.
BigNumber
A large number not representable as a Number or Double.
This library does not attempt to parse this.
VerbatimString
A string to be displayed without any escaping or filtering.
Array
An array of frames.
Map
An unordered map of key-value pairs.
According to the spec keys can be any other RESP3 data type. However, it doesn’t make sense to implement Hash
for certain aggregate types. The can_hash function can be used to
detect this.
Set
An unordered collection of other frames with a uniqueness constraint.
Push
Out-of-band data.
Hello
A special frame type used when first connecting to the server to describe the protocol version and optional credentials.
ChunkedString(Vec<u8>)
One chunk of a streaming blob.
Implementations
sourceimpl OwnedFrame
impl OwnedFrame
sourcepub fn into_bytes_frame(self) -> BytesFrame
Available on crate feature bytes only.
pub fn into_bytes_frame(self) -> BytesFrame
bytes only.Move the frame contents into a new BytesFrame.