Struct redis_protocol::resp3::types::StreamedRangeFrame
source · pub struct StreamedRangeFrame {
pub kind: FrameKind,
pub attributes: Option<RangeAttributes>,
}Available on crate feature
resp3 only.Expand description
A frame type representing ranges into an associated buffer that contains the starting portion of a streaming frame.
Fields
kind: FrameKindattributes: Option<RangeAttributes>Implementations
sourceimpl StreamedRangeFrame
impl StreamedRangeFrame
sourcepub fn add_attributes(&mut self, attributes: RangeAttributes)
pub fn add_attributes(&mut self, attributes: RangeAttributes)
Add range attributes to the frame.