Module redis_protocol::types
source · Expand description
Common types across RESP versions.
Constants
- Terminating bytes between frames.
- The prefix on pubsub messages from a pattern matching subscription.
- The prefix on normal pubsub messages.
- Prefix on RESP3 push pubsub messages.
- The number of slots in a Redis cluster.
- The prefix on pubsub messages from a shard channel subscription.