Enum redis_protocol::resp3::types::BytesFrame
source · pub enum BytesFrame {
Show 16 variants
BlobString {
data: Bytes,
attributes: Option<BytesAttributes>,
},
BlobError {
data: Bytes,
attributes: Option<BytesAttributes>,
},
SimpleString {
data: Bytes,
attributes: Option<BytesAttributes>,
},
SimpleError {
data: Str,
attributes: Option<BytesAttributes>,
},
Boolean {
data: bool,
attributes: Option<BytesAttributes>,
},
Null,
Number {
data: i64,
attributes: Option<BytesAttributes>,
},
Double {
data: f64,
attributes: Option<BytesAttributes>,
},
BigNumber {
data: Bytes,
attributes: Option<BytesAttributes>,
},
VerbatimString {
data: Bytes,
format: VerbatimStringFormat,
attributes: Option<BytesAttributes>,
},
Array {
data: Vec<BytesFrame>,
attributes: Option<BytesAttributes>,
},
Map {
data: FrameMap<BytesFrame, BytesFrame>,
attributes: Option<BytesAttributes>,
},
Set {
data: FrameSet<BytesFrame>,
attributes: Option<BytesAttributes>,
},
Push {
data: Vec<BytesFrame>,
attributes: Option<BytesAttributes>,
},
Hello {
version: RespVersion,
auth: Option<(Str, Str)>,
setname: Option<Str>,
},
ChunkedString(Bytes),
}resp3 and bytes only.Variants
BlobString
A blob of bytes.
BlobError
A blob representing an error.
SimpleString
A small string.
The internal data type is Bytes in order to support callers that use this interface to parse a MONITOR
stream.
SimpleError
A small string representing an error.
Boolean
A boolean type.
Null
A null type.
Number
A signed 64-bit integer.
Double
A signed 64-bit floating point number.
BigNumber
A large number not representable as a Number or Double.
This library does not attempt to parse this.
VerbatimString
A string to be displayed without any escaping or filtering.
Array
An array of frames.
Map
An unordered map of key-value pairs.
According to the spec keys can be any other RESP3 data type. However, it doesn’t make sense to implement Hash
for certain aggregate types. The can_hash function can be used to
detect this.
Set
An unordered collection of other frames with a uniqueness constraint.
Push
Out-of-band data.
Hello
A special frame type used when first connecting to the server to describe the protocol version and optional credentials.
ChunkedString(Bytes)
One chunk of a streaming blob.
Implementations
sourceimpl BytesFrame
impl BytesFrame
sourcepub fn to_owned_frame(&self) -> OwnedFrame
pub fn to_owned_frame(&self) -> OwnedFrame
Copy the frame contents into a new OwnedFrame.